
## CATO-CLI - query.site.secondaryAwsVSocket:
[Click here](https://api.catonetworks.com/documentation/#query-secondaryAwsVSocket) for documentation on this operation.

### Usage for query.site.secondaryAwsVSocket:

`catocli query site secondaryAwsVSocket -h`

`catocli query site secondaryAwsVSocket <json>`

`catocli query site secondaryAwsVSocket "$(cat < secondaryAwsVSocket.json)"`

`catocli query site secondaryAwsVSocket '{"socketId": "ID"}'`

#### Operation Arguments for query.site.secondaryAwsVSocket ####
`accountId` [ID] - (required) N/A 
`socketId` [ID] - (required) N/A 
